##  Inserting a Diagram into a Confluence Page
The process for adding a diagram is like the process for adding a report. You can add both free draw and data flow diagrams to Confluence pages.
To insert an SAP LeanIX diagram to a Confluence page, follow these steps:
  1. Choose + > Other Macros > SAP LeanIX. You can find it under External content or by using the search field.
  2. On the Diagram tab, select the desired diagram. You’ll see a live preview of your diagram in the configuration window. ![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2750ff0d7a44101488b5838fdc1263fa_LowRes.png)
  3. Optional: Adjust the width and height. By default, the height is set to 600px and the width is set to 100%.
  4. Choose Insert to embed the diagram in your Confluence page.
